@@ -37,18 +37,35 @@ def new():
 @click.option("-a", "--apt", multiple=True)
 @click.option("-b", "--brew", multiple=True)
 @click.option("-d", "--dnf", multiple=True)
-def eat(apt, brew, dnf):
+@click.option("-s", "--snap", multiple=True)
+def eat(apt, brew, dnf, snap):
     """Ingest packages and applications."""
-    pass
+    for pkg in apt:
+        print(de.eat_package("apt", pkg))
+    for pkg in brew:
+        print(de.eat_package("brew", pkg))
+    for pkg in dnf:
+        print(de.eat_package("dnf", pkg))
+    for pkg in snap:
+        print(de.eat_package("snap", pkg))
+
 
 
 @lfnt_command
 @click.option("-a", "--apt", multiple=True)
 @click.option("-b", "--brew", multiple=True)
 @click.option("-d", "--dnf", multiple=True)
-def vomit():
+@click.option("-s", "--snap", multiple=True)
+def puke(apt, brew, dnf, snap):
     """Eject packages and applications."""
-    pass
+    for pkg in apt:
+        print(de.puke_package("apt", pkg))
+    for pkg in brew:
+        print(de.puke_package("brew", pkg))
+    for pkg in dnf:
+        print(de.puke_package("dnf", pkg))
+    for pkg in snap:
+        print(de.puke_package("snap", pkg))
 
 
 @lfnt_command
