@@ -7,11 +7,17 @@ from click_configfile import matches_section
 
 
 def run_command(command):
-    return subprocess.run(
-        command,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-    )
+    command_result = None
+    try:
+        command_result = subprocess.run(
+            command,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+    except Exception:
+        pass
+
+    return command_result
 
 
 def get_system():
@@ -39,15 +45,15 @@ def get_system():
 
 def get_packages():
     all_packages = {}
-    for pkgmgr in ["apt", "brew", "poetry"]:
+    for pkgmgr in ["apt", "brew", "dnf", "snap"]:
         which_cmd = run_command(["which", pkgmgr])
-        if which_cmd.returncode < 1:
+        if which_cmd is not None and which_cmd.returncode < 1:
             if pkgmgr == "apt":
                 pkgs = run_command(["apt-mark", "showmanual"])
             if pkgmgr == "brew":
                 pkgs = run_command(["brew", "leaves"])
-            if pkgmgr == "poetry":
-                pkgs = run_command(["poetry", "show"])
+            if pkgmgr == "dnf":
+                pkgs = run_command(["dnf", "list", "installed"])
             all_packages[pkgmgr] = pkgs.stdout.decode().splitlines()
     return all_packages
 
@@ -55,6 +61,7 @@ def get_packages():
 class LocalEnv:
     def __init__(self):
         self.system = get_system()
+        self.shell = os.getenv("SHELL")
         self.packages = None
         pass
 
@@ -65,6 +72,7 @@ class LocalEnv:
         return {
             "system": self.system,
             "packages": self.packages,
+            "shell": self.shell,
         }
 
 
@@ -105,3 +113,22 @@ class DigestiveSystem:
             "profile": CONTEXT_SETTINGS["default_map"],
             "environment": le.get(),
         }
+
+    def get_package(self, pkgmgr, pkg):
+        pkg_data = run_command([pkgmgr, "info", pkg])
+        return pkg_data.stdout.decode().splitlines()
+
+    def eat_package(self, pkgmgr, pkg):
+        action = "install"
+        command = [pkgmgr, action, pkg]
+        if pkgmgr == "snap":
+            command.append("--classic")
+        pkg_data = run_command(command)
+        return pkg_data.stdout.decode().splitlines()
+
+    def puke_package(self, pkgmgr, pkg):
+        action = "uninstall"
+        if pkgmgr in ["apt"]:
+            action = "remove"
+        pkg_data = run_command([pkgmgr, action, pkg])
+        return pkg_data.stdout.decode().splitlines()
